author

# XMLRésuméLibrary: User Guide

artTitle | Element Reference | award

## Name

author — An author of a publication

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
name | IDREF | None
targets | CDATA | None

## Description

The `author` element contains the name of an author of a work or publication. It may also reference a previously-defined `name` through its `name` attribute. In this case, the element will be processed and displayed as if it were actually the referenced name.

### Parents

`author` may be contained in these elements: `pub`

### Attributes

`name`

  The `name` attribute contains the `id` of a `name` element.

  If an `author` element specifies this attribute, it should not have any content. In other words, there should be a single tag with a reference (`<author name="joe.smith"/>`) instead of two tags enclosing content (`<author>Joe Smith</author>`).

## See Also

`name`.

## Examples

    <pub>
      <bookTitle>Nuclear Engineering for Dummies</bookTitle>
      <author>Edgar Neutron</author>
    </pub>

    <name id="shirly.mendoza">
      <firstname>Shirly</firstname>
      <surname>Mendoza</surname>
    </name>
    <pub>
      <artTitle>Cooking Wire-Core Pretzels</artTitle>
      <author name="shirly.mendoza"/>
      <bookTitle>Journal of Metal-Reinforced Confections</bookTitle>
    </pub>

artTitle | Element Reference | award